@@ -5,7 +5,7 @@ from django.utils.decorators import method_decorator
 from django.views import generic
 from django.views.decorators.csrf import csrf_exempt
 from django.conf import settings
-from hazinses.models import SNSMessage, UserEmailProfile
+from models import SNSMessage, UserEmailProfile
 
 
 class SNSMessageView(generic.View):
@@ -28,4 +28,4 @@ class SNSMessageView(generic.View):
             useremail.not_send_mail = datetime.now() + datetime.timedelta(
                 days=settings.COMPLAINT_TIMEDELTA)
         useremail.save()
-        return HttpResponse('ok')
\ No newline at end of file
+        return HttpResponse('ok')
